pub struct CacheMetrics { /* private fields */ }Expand description
Cache metrics using atomics
Implementations
Sourceimpl CacheMetrics
impl CacheMetrics
Sourcepub fn record_hit(&self, lookup_time_ns: u64, timestamp: u64)
pub fn record_hit(&self, lookup_time_ns: u64, timestamp: u64)
Record a cache hit with the given lookup time
Sourcepub fn record_miss(&self, lookup_time_ns: u64, timestamp: u64)
pub fn record_miss(&self, lookup_time_ns: u64, timestamp: u64)
Record a cache miss with the given lookup time
Sourcepub fn record_eviction(&self, timestamp: u64)
pub fn record_eviction(&self, timestamp: u64)
Record a cache eviction
Sourcepub fn snapshot(&self) -> CacheSnapshot
pub fn snapshot(&self) -> CacheSnapshot
Produce a serializable snapshot of the current cache metrics
Sourcepub fn has_issues(&self) -> bool
pub fn has_issues(&self) -> bool
Check whether this cache is exhibiting issues such as low hit rate or slow lookups