pub struct OperationMetrics { /* private fields */ }Expand description
Operation metrics using atomics
Implementations
Sourceimpl OperationMetrics
impl OperationMetrics
Sourcepub fn record_operation(&self, duration_ns: u64, timestamp: u64, is_error: bool)
pub fn record_operation(&self, duration_ns: u64, timestamp: u64, is_error: bool)
Record a single operation execution with its duration and error status
Sourcepub fn snapshot(&self) -> OperationSnapshot
pub fn snapshot(&self) -> OperationSnapshot
Produce a serializable snapshot of the current operation metrics
Sourcepub fn is_problematic(&self) -> bool
pub fn is_problematic(&self) -> bool
Check whether this operation is exhibiting problematic performance