pub struct OperationTimer { /* private fields */ }Expand description
Operation timer that tracks elapsed time for a named operation
Implementations
Sourceimpl OperationTimer
impl OperationTimer
Sourcepub fn finish_with_error(self)
pub fn finish_with_error(self)
Mark the timed operation as finished with an error
Sourcepub fn current_duration(&self) -> Duration
pub fn current_duration(&self) -> Duration
Return the duration elapsed since the timer started