Module query_cache

Module query_cache 

Query caching system for semantic search results

This is a cleaned version of the query cache with removed unused code. All functionality is preserved, but unused components have been removed.

Structs

CachedQuery
A cached query with atomic access tracking
QueryCache
Query cache using DashMap and atomic operations
QueryCacheConfig
Configuration for query cache
QueryCacheStats
Cache statistics using atomic operations
QueryCacheStatsSnapshot
Snapshot of cache statistics for reporting