Module performance

Module performance 

Runtime performance monitoring: operation timers, cache trackers, and health snapshots.

Structs

CacheMetrics
Cache metrics using atomics
CacheSnapshot
Snapshot of a single cache’s metrics
OperationMetrics
Operation metrics using atomics
OperationSnapshot
Snapshot of a single operation’s metrics
OperationTimer
Operation timer that tracks elapsed time for a named operation
PerformanceMonitor
Performance monitor using atomic operations
PerformanceSnapshot
Serializable performance snapshot

Functions

get_monitor
Retrieve the global performance monitor, if initialized
init_monitoring
Initialize the global performance monitor with an optional session identifier
start_timer
Start a timer for the named operation using the global monitor